@@ -126,7 +126,7 @@ def tileByCycles2(g):
 
 
 
-def tile(pairs, Nnode):
+def tile(pairs, Nnode=None):
     """
     Nnode and seed are dummpy parameters
     for the compatibility with c++ codes.
